@@ -103,9 +103,8 @@ sub get_mixed_hash_args_ordered {
 
 # returns \0 and \1 as 0 and 1, and returns 0 and 1 as 0 and 1
 sub jstrue {
-	my $v = shift;
-	ref($v) eq 'SCALAR' and return $$v;
-	return $v;
+  my $v = shift;
+  ref($v) && ref($v) eq 'SCALAR' ? $$v : $v;
 }
 
 
